@@ -1,5 +1,5 @@
 """
-Structure for aiobotocore-stubs module.
+Structure for types-aiobotocore module.
 """
 
 from collections.abc import Iterable
@@ -17,7 +17,7 @@ from mypy_boto3_builder.type_annotations.type_literal import TypeLiteral
 
 class AioBotocoreStubsPackage(Package):
     """
-    Structure for boto3-stubs module.
+    Structure for types-aiobotocore module.
     """
 
     def __init__(
@@ -65,16 +65,6 @@ class AioBotocoreStubsPackage(Package):
                     "create_credential_resolver",
                     "create_credential_resolver",
                 ),
-                ImportRecord(
-                    ImportString("aiobotocore", "handlers"),
-                    "inject_presigned_url_ec2",
-                    "inject_presigned_url_ec2",
-                ),
-                ImportRecord(
-                    ImportString("aiobotocore", "handlers"),
-                    "inject_presigned_url_rds",
-                    "inject_presigned_url_rds",
-                ),
                 ImportRecord(
                     ImportString("aiobotocore", "hooks"),
                     "AioHierarchicalEmitter",
@@ -85,22 +75,8 @@ class AioBotocoreStubsPackage(Package):
                     "AioResponseParserFactory",
                     "AioResponseParserFactory",
                 ),
-                ImportRecord(
-                    ImportString("aiobotocore", "signers"),
-                    "add_generate_db_auth_token",
-                    "add_generate_db_auth_token",
-                ),
-                ImportRecord(
-                    ImportString("aiobotocore", "signers"),
-                    "add_generate_presigned_post",
-                    "add_generate_presigned_post",
-                ),
-                ImportRecord(
-                    ImportString("aiobotocore", "signers"),
-                    "add_generate_presigned_url",
-                    "add_generate_presigned_url",
-                ),
                 ImportRecord(ImportString("botocore", "model"), "ServiceModel"),
+                ImportRecord(ImportString("botocore", "session"), "EVENT_ALIASES", "EVENT_ALIASES"),
                 ImportRecord(ImportString("botocore", "session"), "Session"),
                 ImportRecord(ImportString("typing"), "Any"),
                 ImportRecord(ImportString("typing"), "List"),
